pub struct Row<W> { /* private fields */ }Expand description
A container that distributes its contents horizontally.
Example
use iced::widget::{button, row};
#[derive(Debug, Clone)]
enum Message {
// ...
}
fn view(state: &State) -> impl Widget<Message> {
row![
"I am to the left!",
button("I am in the middle!"),
"I am to the right!",
]
}Implementations
Sourceimpl<W> Row<W>
impl<W> Row<W>
Sourcepub fn with_capacity(capacity: usize) -> Row<W>
pub fn with_capacity(capacity: usize) -> Row<W>
Creates a Row with the given capacity.
Sourcepub fn with_children(children: impl IntoIterator<Item = W>) -> Row<W>where
W: Meta,
pub fn with_children(children: impl IntoIterator<Item = W>) -> Row<W>where
W: Meta,
Creates a Row with the given widgets.
Sourcepub fn from_vec(children: Vec<W>) -> Row<W>
pub fn from_vec(children: Vec<W>) -> Row<W>
Creates a Row from an already allocated Vec.
Keep in mind that the Row will not inspect the Vec, which means
it won’t automatically adapt to the sizing strategy of its contents.
If any of the children have a Length::Fill strategy, you will need to
call Row::width or Row::height accordingly.
Sourcepub fn spacing(self, amount: impl Into<Pixels>) -> Row<W>
pub fn spacing(self, amount: impl Into<Pixels>) -> Row<W>
Sets the horizontal spacing between elements.
Custom margins per element do not exist in iced. You should use this method instead! While less flexible, it helps you keep spacing between elements consistent.
Sourcepub fn align_y(self, align: impl Into<Vertical>) -> Row<W>
pub fn align_y(self, align: impl Into<Vertical>) -> Row<W>
Sets the vertical alignment of the contents of the Row .
Sourcepub fn clip(self, clip: bool) -> Row<W>
pub fn clip(self, clip: bool) -> Row<W>
Sets whether the contents of the Row should be clipped on
overflow.